Struct Metric
pub struct Metric {
pub label: Vec<LabelPair>,
pub gauge: MessageField<Gauge>,
pub counter: MessageField<Counter>,
pub summary: MessageField<Summary>,
pub untyped: MessageField<Untyped>,
pub histogram: MessageField<Histogram>,
pub timestamp_ms: Option<i64>,
pub special_fields: SpecialFields,
}Fields
label: Vec<LabelPair>gauge: MessageField<Gauge>counter: MessageField<Counter>summary: MessageField<Summary>untyped: MessageField<Untyped>histogram: MessageField<Histogram>timestamp_ms: Option<i64>special_fields: SpecialFieldsImplementations
impl Metric
impl Metric
pub fn new() -> Metric
pub fn timestamp_ms(&self) -> i64
pub fn clear_timestamp_ms(&mut self)
pub fn has_timestamp_ms(&self) -> bool
pub fn set_timestamp_ms(&mut self, v: i64)
impl Metric
impl Metric
pub fn from_label(label: Vec<LabelPair>) -> Metric
pub fn from_label(label: Vec<LabelPair>) -> Metric
Creates a new metric with the specified label pairs.
pub fn from_gauge(gauge: Gauge) -> Metric
pub fn from_gauge(gauge: Gauge) -> Metric
Creates a new metric with the specified gauge value.
pub fn get_timestamp_ms(&self) -> i64
👎Deprecated since 0.14.0: Please use .timestamp_ms() instead
pub fn get_timestamp_ms(&self) -> i64
Please use .timestamp_ms() instead
Returns the timestamp of this metric.
pub fn get_summary(&self) -> &MessageField<Summary>
pub fn get_summary(&self) -> &MessageField<Summary>
Returns the summary of this metric.
pub fn set_summary(&mut self, summary: Summary)
pub fn set_summary(&mut self, summary: Summary)
Sets the summary of this metric to the specified summary.
pub fn get_counter(&self) -> &MessageField<Counter>
pub fn get_counter(&self) -> &MessageField<Counter>
Returns the value of the counter for this metric.
pub fn set_counter(&mut self, counter: Counter)
pub fn set_counter(&mut self, counter: Counter)
Sets the counter of this metric to the specified counter.
pub fn take_label(&mut self) -> Vec<LabelPair>
pub fn take_label(&mut self) -> Vec<LabelPair>
Returns all label pairs associated with ownership.
pub fn get_histogram(&self) -> &MessageField<Histogram>
pub fn get_histogram(&self) -> &MessageField<Histogram>
Returns the histogram of this metric.
pub fn set_histogram(&mut self, histogram: Histogram)
pub fn set_histogram(&mut self, histogram: Histogram)
Sets the histogram of this metric to the specified histogram.